==> haskell-string-interpolate-0.3.4.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-6DxkUhu9ocOJBNt5zPVM3c
key:                  string-interpolate-0.3.4.0-6DxkUhu9ocOJBNt5zPVM3c
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  d17d9394e51c0f7c3f4deba649a55831
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-6DxkUhu9ocOJBNt5zPVM3c
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    haskell-src-meta-0.8.14-nS4juMBwVY3TwP6a7Vlpj
    split-0.2.5-fPWkUXEXZHvXnPhPWCGf template-haskell-2.18.0.0
    text-1.2.5.0 text-conversions-0.3.1.1-BiOgqsxkRNVG8Z7OJWP5Hg
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-interpolate-0.3.4.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-interpolate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 string-interpolate
version:              0.3.4.0
visibility:           public
id:                   string-interpolate-0.3.4.0-7qqQRaKYA1n2DSaDJmbY0F
key:                  string-interpolate-0.3.4.0-7qqQRaKYA1n2DSaDJmbY0F
license:              BSD-3-Clause
copyright:            2019-2024 William Yao
maintainer:           williamyaoh@gmail.com
author:               William Yao
homepage:
    https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md

synopsis:
    Haskell string/text/bytestring interpolation that just works

description:
    Unicode-aware string interpolation that handles all textual types.

    See the README at <https://gitlab.com/williamyaoh/string-interpolate/blob/master/README.md> for more info.

category:             Data, Text
abi:                  93dd7a3aab239af05772d26ab8919d7e
exposed:              True
exposed-modules:
    Data.String.Interpolate Data.String.Interpolate.Conversion
    Data.String.Interpolate.Conversion.ByteStringSink
    Data.String.Interpolate.Conversion.TextSink
    Data.String.Interpolate.Parse Data.String.Interpolate.Types

hidden-modules:
    Data.String.Interpolate.Conversion.Classes
    Data.String.Interpolate.Conversion.Encoding
    Data.String.Interpolate.Lines Data.String.Interpolate.Whitespace
    Paths_string_interpolate

import-dirs:          /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/string-interpolate-0.3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-interpolate
hs-libraries:         HSstring-interpolate-0.3.4.0-7qqQRaKYA1n2DSaDJmbY0F
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    haskell-src-exts-1.23.1-AENnvMzOJnRLlGbXypFMpv
    haskell-src-meta-0.8.14-nS4juMBwVY3TwP6a7Vlpj
    split-0.2.5-fPWkUXEXZHvXnPhPWCGf template-haskell-2.18.0.0
    text-1.2.5.0 text-conversions-0.3.1.1-BiOgqsxkRNVG8Z7OJWP5Hg
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:
    /usr/share/doc/haskell-string-interpolate/html/string-interpolate.haddock

haddock-html:         /usr/share/doc/haskell-string-interpolate/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
